@@ -5,7 +5,7 @@
 #include "GUI_output.h"
 
 
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
 	SDL_Surface *screen;
 
